//
//  bt_att_data.c
//
//  Bluetooth Protocol Stack - Attribute Database manager - Database content
//   <Sample data>
//
//  Update history
//  ---------- ----- -------------------------------------------
//  2015.02.20 v0.3b The new "bt_att_data.c" is independent of the ATT database user data
//

#include "bt_spec_gatt.h"
#include "bt_att_db.h"
#include "bt_att_data.h"

#define UINT16(a)  ATT_UINT16_DATA(a)       // Alias (Short name)
#define UINT32(a)  ATT_UINT32_DATA(a)       // Alias
#define UU16(a)    ATT_UUID16TO128_DATA(a)  // Alias
#define UU128(a)   ATT_UUID128_DATA(a)      // Alias

//
//  ATT Database  -  Sample Service
//
struct bt_attDb bt_attDb = {
    35,
    {// Handle  Type                                                                                  Len  Values                                                                                                                       Property
        {0x0001,{UU16(GATT_Attribute_Types_Primary_Service)},                                          2,  {UINT16(GATT_Services_Generic_Access_Profile)},                                                                              ATT_DB_PROPERTIES_READ},
        {0x0002,    {UU16(GATT_Attribute_Types_Characteristic)},                                       5,  {GATT_Characteristic_Properties_Read, UINT16(0x0003), UINT16(GATT_Characteristic_Types_Device_Name)},                        ATT_DB_PROPERTIES_READ},
        {0x0003,        {UU16(GATT_Characteristic_Types_Device_Name)},                                14,  {'B', 'L', 'E', ' ', 'A', 'T', 'T', ' ', 'S', 'A', 'M', 'P', 'L', 'E', '\0'},                                                ATT_DB_PROPERTIES_READ},
        {0x0004,    {UU16(GATT_Attribute_Types_Characteristic)},                                       5,  {GATT_Characteristic_Properties_Read, UINT16(0x0005), UINT16(GATT_Characteristic_Types_Appearance)},                         ATT_DB_PROPERTIES_READ},
        {0x0005,        {UU16(GATT_Characteristic_Types_Appearance)},                                  2,  {UINT16(GATT_Characteristic_Appearance_Category_Generic_Computer)},                                                          ATT_DB_PROPERTIES_READ},

        {0x0011,{UU16(GATT_Attribute_Types_Primary_Service)},                                          2,  {UINT16(GATT_Services_Generic_Attribute_Profile)},                                                                           ATT_DB_PROPERTIES_READ},
        {0x0012,    {UU16(GATT_Attribute_Types_Characteristic)},                                       5,  {GATT_Characteristic_Properties_Read|GATT_Characteristic_Properties_Write_Without_Response|GATT_Characteristic_Properties_Indicate,
                                                                                                            UINT16(0x0013), UINT16(GATT_Characteristic_Types_Service_Changed)},                                                         ATT_DB_PROPERTIES_READ},
        {0x0013,        {UU16(GATT_Characteristic_Types_Service_Changed)},                             4,  {UINT16(0x0001), UINT16(0xffff)},                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x0014,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Extended_Properties)},    2,  {UINT16(GATT_Characteristic_Extended_Properties_Writable_Auxiliaries)},                                                      ATT_DB_PROPERTIES_READ},
        {0x0015,        {UU16(GATT_Characteristic_Descriptors_Client_Characteristic_Configuration)},   2,  {UINT16(0x0000)},                                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},

        {0x1000,{UU16(GATT_Attribute_Types_Primary_Service)},                                         16,  {UU128(UUID_MY_SERVICE)},                                                                                                    ATT_DB_PROPERTIES_READ},
//-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
        {0x1001,    {UU16(GATT_Attribute_Types_Characteristic)},                                      19,  {GATT_Characteristic_Properties_Read | GATT_Characteristic_Properties_Write | GATT_Characteristic_Properties_Notify,
                                                                                                            UINT16(0x1002), UU128(UUID_MY_CHAR0)},                                                                                      ATT_DB_PROPERTIES_READ},
        {0x1002,        {UU128(UUID_MY_CHAR0)},                                                        1,  {0x00},                                                                                                                      ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x1003,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Extended_Properties)},    2,  {UINT16(GATT_Characteristic_Extended_Properties_Writable_Auxiliaries)},                                                      ATT_DB_PROPERTIES_READ},
        {0x1004,        {UU16(GATT_Characteristic_Descriptors_Client_Characteristic_Configuration)},   2,  {UINT16(0x0000)},                                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x1005,        {UU16(GATT_Characteristic_Descriptors_Characteristic_User_Description)},      13,  {'L', 'E', 'D', ' ', 'C', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e'},                                                           ATT_DB_PROPERTIES_READ},
        {0x1006,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Format)},                 7,  {GATT_Characteristic_Format_boolean, 0, UINT16(GATT_Characteristic_Unit_unitless),
                                                                                                            GATT_Characteristic_Namespace_Bluetooth_SIG_Assigned_Numbers, UINT16(GATT_Characteristic_Description_Bluetooth_SIG_inside)},ATT_DB_PROPERTIES_READ},
//-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
        {0x1011,    {UU16(GATT_Attribute_Types_Characteristic)},                                      19,  {GATT_Characteristic_Properties_Read | GATT_Characteristic_Properties_Notify, UINT16(0x1012), UU128(UUID_MY_CHAR1)},         ATT_DB_PROPERTIES_READ},
        {0x1012,        {UU128(UUID_MY_CHAR1)},                                                        4,  {UINT32(0)},                                                                                                                 ATT_DB_PROPERTIES_READ},
        {0x1013,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Extended_Properties)},    2,  {UINT16(GATT_Characteristic_Extended_Properties_Writable_Auxiliaries)},                                                      ATT_DB_PROPERTIES_READ},
        {0x1014,        {UU16(GATT_Characteristic_Descriptors_Client_Characteristic_Configuration)},   2,  {UINT16(0x0000)},                                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x1015,        {UU16(GATT_Characteristic_Descriptors_Characteristic_User_Description)},      13,  {'A','c','c','e','l','e','r','a','t','i','o','n','X'},                                                                       ATT_DB_PROPERTIES_READ},
        {0x1016,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Format)},                 7,  {GATT_Characteristic_Format_sint32, 0, UINT16(GATT_Characteristic_Unit_acceleration_metres_per_second_squared),
                                                                                                            GATT_Characteristic_Namespace_Bluetooth_SIG_Assigned_Numbers, UINT16(GATT_Characteristic_Description_Bluetooth_SIG_inside)},ATT_DB_PROPERTIES_READ},
//-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
        {0x1021,    {UU16(GATT_Attribute_Types_Characteristic)},                                      19,  {GATT_Characteristic_Properties_Read | GATT_Characteristic_Properties_Notify, UINT16(0x1022), UU128(UUID_MY_CHAR2)},         ATT_DB_PROPERTIES_READ},
        {0x1022,        {UU128(UUID_MY_CHAR2)},                                                        4,  {UINT32(0)},                                                                                                                 ATT_DB_PROPERTIES_READ},
        {0x1023,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Extended_Properties)},    2,  {UINT16(GATT_Characteristic_Extended_Properties_Writable_Auxiliaries)},                                                      ATT_DB_PROPERTIES_READ},
        {0x1024,        {UU16(GATT_Characteristic_Descriptors_Client_Characteristic_Configuration)},   2,  {UINT16(0x0000)},                                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x1025,        {UU16(GATT_Characteristic_Descriptors_Characteristic_User_Description)},      13,  {'A','c','c','e','l','e','r','a','t','i','o','n','Y'},                                                                       ATT_DB_PROPERTIES_READ},
        {0x1026,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Format)},                 7,  {GATT_Characteristic_Format_sint32, 0, UINT16(GATT_Characteristic_Unit_acceleration_metres_per_second_squared),
                                                                                                            GATT_Characteristic_Namespace_Bluetooth_SIG_Assigned_Numbers, UINT16(GATT_Characteristic_Description_Bluetooth_SIG_inside)},ATT_DB_PROPERTIES_READ},
//-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
        {0x1031,    {UU16(GATT_Attribute_Types_Characteristic)},                                      19,  {GATT_Characteristic_Properties_Read | GATT_Characteristic_Properties_Notify, UINT16(0x1032), UU128(UUID_MY_CHAR3)},         ATT_DB_PROPERTIES_READ},
        {0x1032,        {UU128(UUID_MY_CHAR3)},                                                        4,  {UINT32(0)},                                                                                                                 ATT_DB_PROPERTIES_READ},
        {0x1033,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Extended_Properties)},    2,  {UINT16(GATT_Characteristic_Extended_Properties_Writable_Auxiliaries)},                                                      ATT_DB_PROPERTIES_READ},
        {0x1034,        {UU16(GATT_Characteristic_Descriptors_Client_Characteristic_Configuration)},   2,  {UINT16(0x0000)},                                                                                                            ATT_DB_PROPERTIES_READ | ATT_DB_PROPERTIES_WRITE},
        {0x1035,        {UU16(GATT_Characteristic_Descriptors_Characteristic_User_Description)},      13,  {'A','c','c','e','l','e','r','a','t','i','o','n','Z'},                                                                       ATT_DB_PROPERTIES_READ},
        {0x1036,        {UU16(GATT_Characteristic_Descriptors_Characteristic_Format)},                 7,  {GATT_Characteristic_Format_sint32, 0, UINT16(GATT_Characteristic_Unit_acceleration_metres_per_second_squared),
                                                                                                            GATT_Characteristic_Namespace_Bluetooth_SIG_Assigned_Numbers, UINT16(GATT_Characteristic_Description_Bluetooth_SIG_inside)},ATT_DB_PROPERTIES_READ},
    }
};
