//
//  Global initialize
//
#include <stddef.h>                     // Need a sys_devcon.h (size_t)
#include "system/devcon/sys_devcon.h"   // Harmony
#include "system/clk/sys_clk.h"         // Harmony
#include "system/tmr/sys_tmr.h"         // Harmony
#include "system/ports/sys_ports.h"     // Harmony
#include "system/int/sys_int.h"         // Harmony
#include "usb/usb_host.h"               // Harmony
#include "usb/usb_host_bluetooth.h"     // Harmony+
#include "driver/tmr/drv_tmr.h"         // Harmony

#include "system_config.h"
#include "system_definitions.h"
#include "bsp_config.h"
#include "app.h"


//
// PIC32MX250F128B External crystal is 12MHz
//
  #pragma config POSCMOD    = HS          // Primary Oscillator   XT=Crystal(4..10MHz)/HS=Crystal(10..25MHz)/EC=ExternalOSC(..40MHz)/OFF
  #pragma config FSOSCEN    = OFF         // Secondary Oscillator ON/OFF

//#pragma config FNOSC      = FRC         // Oscillator Selection = Internal 8MHz
//#pragma config FNOSC      = FRCPLL      // Oscillator Selection = Internal 8MHz / FPLLIDIV * FPLLMUL / FPLLODIV
//#pragma config   FPLLIDIV = DIV_2       //   PLL Input Divider
//#pragma config   FPLLMUL  = MUL_20      //   PLL Multiplier
//#pragma config   FPLLODIV = DIV_2       //   System PLL Output Clock Divider
  #pragma config FNOSC      = PRIPLL      // Oscillator Selection = Primary Oscillator / FPLLIDIV * FPLLMUL / FPLLODIV
  #pragma config   FPLLIDIV = DIV_3       //   PLL Input Divider, 1/2/3/4/5/6/10/12
  #pragma config   FPLLMUL  = MUL_20      //   PLL Multiplier 15/16/17/18/19/20/21/24
  #pragma config   FPLLODIV = DIV_2       //   System PLL Output Clock Divider 1/2/4/8/16/32/64/128
//#pragma config FNOSC      = PRI         // Oscillator Selection = Primary Oscillator
//#pragma config FNOSC      = SOSC        // Oscillator Selection = Secondary Oscillator
//#pragma config FNOSC      = LPRC        // Oscillator Selection = Internal 31.25kHz
//#pragma config FNOSC      = FRCDIV16    // Oscillator Selection = Internal 500kHz
//#pragma config FNOSC      = FRCDIV      // Oscillator Selection = Internal 8MHz / FRCDIV(OSCCON Register,default=2)

  #pragma config OSCIOFNC   = OFF         // CLKO Output Signal Active on the OSCO Pin
  #pragma config IESO       = OFF         // Internal/External Switch Over
  #pragma config FPBDIV     = DIV_8       // Peripheral Clock Divisor, 1/2/4/8
  #pragma config FCKSM      = CSDCMD      // Clock Switching and Monitor Selection
  #pragma config FWDTEN     = OFF         // Watchdog Timer Enable
  #pragma config   WDTPS    = PS1         // Watchdog Timer Postscaler
  #pragma config UPLLEN     = ON          // USB PLL Enable
  #pragma config   UPLLIDIV = DIV_3       //   USB PLL Input Divider, 48MHz = Primary Oscillator / UPLLIDIV * 24 / 2
  #pragma config USERID     = 0xffff      //
  #pragma config FUSBIDIO   = OFF         // RB5
  #pragma config FVBUSONIO  = ON          // RB14

  #pragma config DEBUG      = OFF         //
  #pragma config ICESEL     = ICS_PGx1    // ICSP PGx1(RB0,1)/PGx2(RA0,1)/PGx3(RB10,11)
  #pragma config PWP        = OFF         // Program Flash Write Protect
  #pragma config BWP        = OFF         // Boot Flash Write Protect
  #pragma config CP         = OFF         // Code protection
  #pragma config JTAGEN     = OFF         //

//
//  Control blocks
//
const USB_HOST_TARGET_PERIPHERAL_LIST USBTPList[USB_HOST_TPL_ENTRIES] = {
        {
            TPL_MATCH_CL_SC_P(USB_HOST_BLUETOOTH_CLASS, USB_HOST_BLUETOOTH_SUBCLASS, USB_HOST_BLUETOOTH_PROTOCOL),
            TPL_FLAG_CLASS_SUBCLASS_PROTOCOL,
            &usbHostClassDriverBluetooth
        },
};

uint8_t __attribute__((aligned(512))) endpointTable[USB_HOST_ENDPOINT_TABLE_SIZE];

const USB_HOST_INIT usbHostInitData = {
    .usbID           = USB_ID_1,
    .stopInIdle      = false,
    .suspendInSleep  = false, 
    .endpointTable   = endpointTable,
    .interruptSource = INT_SOURCE_USB_1,
    .nTPLEntries     = USB_HOST_TPL_ENTRIES,
    .usbSpeed        = USB_SPEED_FULL,
    .tplList         = (USB_HOST_TARGET_PERIPHERAL_LIST *) USBTPList,
};

const DRV_TMR_INIT drvTmr0InitData = {
    .moduleInit       = {DRV_TMR_POWER_STATE_IDX0},
    .tmrId            = DRV_TMR_PERIPHERAL_ID_IDX0,
    .clockSource      = DRV_TMR_CLOCK_SOURCE_IDX0, 
    .prescale         = DRV_TMR_PRESCALE_IDX0,
    .mode             = DRV_TMR_OPERATION_MODE_IDX0,
    .interruptSource  = DRV_TMR_INTERRUPT_SOURCE_IDX0,
    .asyncWriteEnable = false,
};

const SYS_TMR_INIT sysTmrInitData = {
    .moduleInit = {SYS_MODULE_POWER_RUN_FULL},
    .drvIndex   = DRV_TMR_INDEX_0,
    .tmrFreq    = 1000,
};

const SYS_DEVCON_INIT sysDevconInit = {
    .moduleInit = {0},
};

SYSTEM_OBJECTS sysObj;


//
//  One time
//
void SYS_Initialize(void* data) {
    SYS_CLK_Initialize(NULL);
    sysObj.sysDevcon = SYS_DEVCON_Initialize(SYS_DEVCON_INDEX_0, (SYS_MODULE_INIT*)&sysDevconInit);
    SYS_DEVCON_PerformanceConfig(SYS_CLK_SystemFrequencyGet());
    SYS_INT_Initialize();
    SYS_PORTS_Initialize();

    sysObj.sysTmr         = SYS_TMR_Initialize(SYS_TMR_INDEX_0, (SYS_MODULE_INIT *)&sysTmrInitData);
    sysObj.drvTmr0        = DRV_TMR_Initialize(DRV_TMR_INDEX_0, (SYS_MODULE_INIT *)&drvTmr0InitData);
    sysObj.usbHostObject0 = USB_HOST_Initialize(USB_HOST_INDEX_0, (SYS_MODULE_INIT *)&usbHostInitData);

    SYS_INT_VectorPrioritySet   (DRV_TMR_INTERRUPT_VECTOR_IDX0, DRV_TMR_INTERRUPT_PRIORITY_IDX0);
    SYS_INT_VectorSubprioritySet(DRV_TMR_INTERRUPT_VECTOR_IDX0, DRV_TMR_INTERRUPT_SUB_PRIORITY_IDX0);
    SYS_INT_VectorPrioritySet   (USB_HOST_INT_VECTOR, USB_HOST_INT_PRIORITY);
    SYS_INT_VectorSubprioritySet(USB_HOST_INT_VECTOR, USB_HOST_INT_SUB_PRIORITY);
    SYS_INT_Enable();

    BSP_Initialize();
    APP_Initialize();
    return;
}
